@@ -33,7 +33,6 @@
 #include <KCalUtils/IncidenceFormatter>
 
 #include <KJob>
-#include <KSystemTimeZone>
 #include <QTextBrowser>
 
 #include <QVBoxLayout>
@@ -51,11 +50,11 @@ void TextBrowser::setSource(const QUrl &name)
     QString uri = name.toString();
     // QTextBrowser for some reason insists on putting // or / in links,
     // this is a crude workaround
-    if (uri.startsWith(QStringLiteral("uid:")) ||
-            uri.startsWith(QStringLiteral("kmail:")) ||
-            uri.startsWith(QStringLiteral("urn:x-ical").section(QLatin1Char(':'), 0, 0)) ||
-            uri.startsWith(QStringLiteral("news:")) ||
-            uri.startsWith(QStringLiteral("mailto:"))) {
+    if (uri.startsWith(QLatin1String("uid:"))
+        || uri.startsWith(QLatin1String("kmail:"))
+        || uri.startsWith(QStringLiteral("urn:x-ical").section(QLatin1Char(':'), 0, 0))
+        || uri.startsWith(QLatin1String("news:"))
+        || uri.startsWith(QLatin1String("mailto:"))) {
         uri.replace(QRegExp(QLatin1String("^([^:]+:)/+")), QStringLiteral("\\1"));
     }
 
@@ -70,12 +69,15 @@ class Q_DECL_HIDDEN IncidenceViewer::Private
 {
 public:
     Private(IncidenceViewer *parent)
-        : mCalendar(Q_NULLPTR), mParent(parent), mParentCollectionFetchJob(Q_NULLPTR),
-          mAttachmentModel(Q_NULLPTR), mDelayedClear(false)
+        : mCalendar(nullptr)
+        , mParent(parent)
+        , mParentCollectionFetchJob(nullptr)
+        , mAttachmentModel(nullptr)
+        , mDelayedClear(false)
     {
         mAttachmentHandler = new AttachmentHandler(parent);
         mBrowser = new TextBrowser;
-        parent->connect(mBrowser, SIGNAL(attachmentUrlClicked(QString)), parent, SLOT(slotAttachmentUrlClicked(QString)));
+        parent->connect(mBrowser, &TextBrowser::attachmentUrlClicked, parent, [this](const QString &str) { slotAttachmentUrlClicked(str); });
     }
 
     void updateView()
@@ -84,9 +86,8 @@ public:
 
         if (mCurrentItem.isValid()) {
             text = KCalUtils::IncidenceFormatter::extensiveDisplayStr(
-                       CalendarSupport::displayName(mCalendar, mParentCollection),
-                       CalendarSupport::incidence(mCurrentItem),
-                       mDate, KSystemTimeZones::local());
+                CalendarSupport::displayName(mCalendar, mParentCollection),
+                CalendarSupport::incidence(mCurrentItem), mDate);
             text.prepend(mHeaderText);
             mBrowser->setHtml(text);
         } else {
@@ -95,16 +96,16 @@ public:
                 mBrowser->setHtml(text);
             }
         }
-
     }
 
     void slotParentCollectionFetched(KJob *job)
     {
-        mParentCollectionFetchJob = 0;
+        mParentCollectionFetchJob = nullptr;
         mParentCollection = Akonadi::Collection();
 
         if (!job->error()) {
-            Akonadi::CollectionFetchJob *fetchJob = qobject_cast<Akonadi::CollectionFetchJob *>(job);
+            Akonadi::CollectionFetchJob *fetchJob
+                = qobject_cast<Akonadi::CollectionFetchJob *>(job);
             if (!fetchJob->collections().isEmpty()) {
                 mParentCollection = fetchJob->collections().at(0);
             }
@@ -115,43 +116,45 @@ public:
 
     void slotAttachmentUrlClicked(const QString &uri)
     {
-        const QString attachmentName =
-            QString::fromUtf8(QByteArray::fromBase64(uri.mid(7).toUtf8()));
+        const QString attachmentName
+            = QString::fromUtf8(QByteArray::fromBase64(uri.mid(7).toUtf8()));
         mAttachmentHandler->view(attachmentName, CalendarSupport::incidence(mCurrentItem));
     }
 
-    Akonadi::ETMCalendar *mCalendar;
-    IncidenceViewer *mParent;
-    TextBrowser *mBrowser;
+    Akonadi::ETMCalendar *mCalendar = nullptr;
+    IncidenceViewer *mParent = nullptr;
+    TextBrowser *mBrowser = nullptr;
     Akonadi::Item mCurrentItem;
     QString mHeaderText;
     QString mDefaultText;
     Akonadi::Collection mParentCollection;
-    Akonadi::CollectionFetchJob *mParentCollectionFetchJob;
-    IncidenceAttachmentModel *mAttachmentModel;
-    AttachmentHandler *mAttachmentHandler;
+    Akonadi::CollectionFetchJob *mParentCollectionFetchJob = nullptr;
+    IncidenceAttachmentModel *mAttachmentModel = nullptr;
+    AttachmentHandler *mAttachmentHandler = nullptr;
     QDate mDate;
-    bool mDelayedClear;
+    bool mDelayedClear = false;
 };
 
 IncidenceViewer::IncidenceViewer(Akonadi::ETMCalendar *calendar, QWidget *parent)
-    : QWidget(parent), d(new Private(this))
+    : QWidget(parent)
+    , d(new Private(this))
 {
     d->mCalendar = calendar;
     init();
 }
 
 IncidenceViewer::IncidenceViewer(QWidget *parent)
-    : QWidget(parent), d(new Private(this))
+    : QWidget(parent)
+    , d(new Private(this))
 {
-    d->mCalendar = Q_NULLPTR;
+    d->mCalendar = nullptr;
     init();
 }
 
 void IncidenceViewer::init()
 {
     QVBoxLayout *layout = new QVBoxLayout(this);
-    layout->setMargin(0);
+    layout->setContentsMargins(0, 0, 0, 0);
 
     d->mBrowser->setOpenLinks(true);
     d->mBrowser->setMinimumHeight(1);
@@ -188,8 +191,8 @@ QDate IncidenceViewer::activeDate() const
 QAbstractItemModel *IncidenceViewer::attachmentModel() const
 {
     if (!d->mAttachmentModel) {
-        d->mAttachmentModel =
-            new IncidenceAttachmentModel(const_cast<IncidenceViewer *>(this));
+        d->mAttachmentModel
+            = new IncidenceAttachmentModel(const_cast<IncidenceViewer *>(this));
     }
     return d->mAttachmentModel;
 }
@@ -231,15 +234,17 @@ void IncidenceViewer::itemChanged(const Akonadi::Item &item)
     }
 
     if (d->mParentCollectionFetchJob) {
-        disconnect(d->mParentCollectionFetchJob, SIGNAL(result(KJob*)), this, SLOT(slotParentCollectionFetched(KJob*)));
+        disconnect(d->mParentCollectionFetchJob, SIGNAL(result(KJob*)), this,
+                   SLOT(slotParentCollectionFetched(KJob*)));
         delete d->mParentCollectionFetchJob;
     }
 
-    d->mParentCollectionFetchJob =
-        new Akonadi::CollectionFetchJob(d->mCurrentItem.parentCollection(),
-                                        Akonadi::CollectionFetchJob::Base, this);
+    d->mParentCollectionFetchJob
+        = new Akonadi::CollectionFetchJob(d->mCurrentItem.parentCollection(),
+                                          Akonadi::CollectionFetchJob::Base, this);
 
-    connect(d->mParentCollectionFetchJob, SIGNAL(result(KJob*)),  this, SLOT(slotParentCollectionFetched(KJob*)));
+    connect(d->mParentCollectionFetchJob, SIGNAL(result(KJob*)), this,
+            SLOT(slotParentCollectionFetched(KJob*)));
 }
 
 void IncidenceViewer::itemRemoved()
